Improve this Doc

# `auto`

## Installation

Implicit module which gets automatically added to each $injector.

## Module Components

### Service

Name | Description
--- | ---
$injector | `$injector` is used to retrieve object instances as defined by provider, instantiate types, invoke methods, and load modules.
$provide | The $provide service has a number of methods for registering components with the $injector. Many of these functions are also exposed on `angular.Module`.